# Table of Contents

- [configuring-collibra-integration](<./configuring-collibra-integration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configuring Collibra Integration](<./Configuring-Collibra-Integration.md>)
  - [Configuring Collibra Integration](<./Configuring-Collibra-Integration/Configuring-Collibra-Integration.md>)
  - [Setting Up Authentication](<./Configuring-Collibra-Integration/Setting-Up-Authentication.md>)
  - [Basic Auth](<./Configuring-Collibra-Integration/Basic-Auth.md>)
  - [OAuth 2.0](<./Configuring-Collibra-Integration/OAuth-2.0.md>)
  - [Credentials Validity](<./Configuring-Collibra-Integration/Credentials-Validity.md>)
  - [Trigger Synchronization](<./Configuring-Collibra-Integration/Trigger-Synchronization.md>)
